@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2015 Vaclav Slavik
+ *  Copyright (C) 2015-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -55,7 +55,7 @@
 namespace
 {
 
-wxString WrapTextAtWidth(const wxString& text_, int width, wxWindow *wnd)
+wxString WrapTextAtWidth(const wxString& text_, int width, Language lang, wxWindow *wnd)
 {
     if (text_.empty())
         return text_;
@@ -65,7 +65,9 @@ wxString WrapTextAtWidth(const wxString& text_, int width, wxWindow *wnd)
     if (!iter)
     {
         UErrorCode err = U_ZERO_ERROR;
-        iter.reset(icu::BreakIterator::createLineInstance(icu::Locale(), err));
+        iter.reset(icu::BreakIterator::createLineInstance(lang.IsValid() ? lang.ToIcu() : icu::Locale(), err));
+        if (!iter)
+            iter.reset(icu::BreakIterator::createLineInstance(icu::Locale::getEnglish(), err));
     }
 
     iter->setText(text);
@@ -148,7 +150,7 @@ void AutoWrappingText::SetAndWrapLabel(const wxString& label)
     wxWindowUpdateLocker lock(this);
     m_text = label;
     m_wrapWidth = GetSize().x;
-    SetLabel(WrapTextAtWidth(label, m_wrapWidth, this));
+    SetLabelText(WrapTextAtWidth(label, m_wrapWidth, m_language, this));
 
     InvalidateBestSize();
     SetMinSize(wxDefaultSize);
@@ -165,7 +167,7 @@ void AutoWrappingText::OnSize(wxSizeEvent& e)
     wxWindowUpdateLocker lock(this);
 
     m_wrapWidth = w;
-    SetLabel(WrapTextAtWidth(m_text, w, this));
+    SetLabel(WrapTextAtWidth(m_text, w, m_language, this));
 
     InvalidateBestSize();
     SetMinSize(wxDefaultSize);
@@ -201,8 +203,14 @@ SelectableAutoWrappingText::SelectableAutoWrappingText(wxWindow *parent, const w
 ExplanationLabel::ExplanationLabel(wxWindow *parent, const wxString& label)
     : AutoWrappingText(parent, label)
 {
-#if defined(__WXOSX__) || defined(__WXGTK__)
+#if defined(__WXOSX__)
     SetWindowVariant(wxWINDOW_VARIANT_SMALL);
+#elif defined(__WXGTK__)
+    #if wxCHECK_VERSION(3,1,0)
+        SetWindowVariant(wxWINDOW_VARIANT_SMALL);
+    #else
+        SetFont(GetFont().Smaller());
+    #endif
 #endif
 #ifndef __WXGTK__
     SetForegroundColour(GetTextColor());
@@ -223,8 +231,14 @@ wxColour ExplanationLabel::GetTextColor()
 SecondaryLabel::SecondaryLabel(wxWindow *parent, const wxString& label)
     : wxStaticText(parent, wxID_ANY, label)
 {
-#if defined(__WXOSX__) || defined(__WXGTK__)
+#if defined(__WXOSX__)
     SetWindowVariant(wxWINDOW_VARIANT_SMALL);
+#elif defined(__WXGTK__)
+    #if wxCHECK_VERSION(3,1,0)
+        SetWindowVariant(wxWINDOW_VARIANT_SMALL);
+    #else
+        SetFont(GetFont().Smaller());
+    #endif
 #endif
 #ifndef __WXGTK__
     SetForegroundColour(GetTextColor());
@@ -232,7 +246,7 @@ SecondaryLabel::SecondaryLabel(wxWindow *parent, const wxString& label)
 }
 
 
-LearnMoreLink::LearnMoreLink(wxWindow *parent, const wxString& url, wxString label)
+LearnMoreLink::LearnMoreLink(wxWindow *parent, const wxString& url, wxString label, wxWindowID winid)
 {
     if (label.empty())
     {
@@ -243,7 +257,7 @@ LearnMoreLink::LearnMoreLink(wxWindow *parent, const wxString& url, wxString lab
 #endif
     }
 
-    wxHyperlinkCtrl::Create(parent, wxID_ANY, label, url);
+    wxHyperlinkCtrl::Create(parent, winid, label, url);
     SetNormalColour("#2F79BE");
     SetVisitedColour("#2F79BE");
     SetHoverColour("#3D8DD5");
@@ -257,7 +271,8 @@ LearnMoreLink::LearnMoreLink(wxWindow *parent, const wxString& url, wxString lab
 
 wxObject *LearnMoreLinkXmlHandler::DoCreateResource()
 {
-    auto w = new LearnMoreLink(m_parentAsWindow, GetText("url"), GetText("label"));
+    auto w = new LearnMoreLink(m_parentAsWindow, GetText("url"), GetText("label"), GetID());
+    w->SetName(GetName());
     SetupWindow(w);
     return w;
 }
