@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 1999-2014 Vaclav Slavik
+ *  Copyright (C) 1999-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,10 @@
 #include <wx/intl.h>
 #include <wx/docview.h>
 
+#include "prefsdlg.h"
+
 class WXDLLIMPEXP_FWD_BASE wxConfigBase;
+class WXDLLIMPEXP_FWD_BASE wxSingleInstanceChecker;
 class WXDLLIMPEXP_FWD_CORE wxMenuBar;
 
 
@@ -43,7 +46,7 @@ class PoeditApp : public wxApp
         PoeditApp();
         ~PoeditApp();
 
-        /** wxWin initalization hook. Shows PoeditFrame and initializes
+        /** wxWin initialization hook. Shows PoeditFrame and initializes
             configuration entries to default values if they were missing.
          */
         virtual bool OnInit();
@@ -53,6 +56,7 @@ class PoeditApp : public wxApp
 
         /// Returns Poedit version string.
         wxString GetAppVersion() const;
+        wxString GetAppBuildNumber() const;
         bool IsBetaVersion() const;
         bool CheckForBetaUpdates() const;
 
@@ -65,9 +69,10 @@ class PoeditApp : public wxApp
         wxFileHistory& FileHistory() { return m_history; }
 #endif
 
-#ifdef __WXMAC__
+#ifdef __WXOSX__
         virtual void MacOpenFiles(const wxArrayString& names) { OpenFiles(names); }
         virtual void MacNewFile() { OpenNewFile(); }
+        virtual void MacOpenURL(const wxString &url) { HandleCustomURI(url); }
 #endif
 
         void EditPreferences();
@@ -85,6 +90,7 @@ class PoeditApp : public wxApp
         void InstallOpenRecentMenu(wxMenuBar *bar);
         void OnIdleInstallOpenRecentMenu(wxIdleEvent& event);
         virtual void OSXOnWillFinishLaunching();
+        void OnCloseWindowCommand(wxCommandEvent& event);
 #endif
 
     protected:
@@ -93,17 +99,20 @@ class PoeditApp : public wxApp
             upgrade to new version.)
          */
         void SetDefaultCfg(wxConfigBase *cfg);
-        void SetDefaultParsers(wxConfigBase *cfg);
+        void SetDefaultExtractors(wxConfigBase *cfg);
         
         void OnInitCmdLine(wxCmdLineParser& parser);
         bool OnCmdLineParsed(wxCmdLineParser& parser);
         
     private:
+        void HandleCustomURI(const wxString& uri);
+
         void SetupLanguage();
 
         // App-global menu commands:
         void OnNew(wxCommandEvent& event);
         void OnOpen(wxCommandEvent& event);
+        void OnOpenFromCrowdin(wxCommandEvent& event);
 #ifndef __WXOSX__
         void OnOpenHist(wxCommandEvent& event);
 #endif
@@ -129,6 +138,17 @@ class PoeditApp : public wxApp
 #else
         wxFileHistory m_history;
 #endif
+
+        std::unique_ptr<PoeditPreferencesEditor> m_preferences;
+
+        std::unique_ptr<wxLocale> m_locale;
+
+#ifndef __WXOSX__
+        class RemoteServer;
+        class RemoteClient;
+        std::unique_ptr<RemoteServer> m_remoteServer;
+        std::unique_ptr<wxSingleInstanceChecker> m_instanceChecker;
+#endif
 };
 
 DECLARE_APP(PoeditApp);
