@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2000-2014 Vaclav Slavik
+ *  Copyright (C) 2000-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -29,28 +29,37 @@
 #include <wx/txtstrm.h>
 #include <wx/string.h>
 #include <wx/intl.h>
-#include <wx/regex.h>
 #include <wx/stdpaths.h>
+#include <wx/translation.h>
 #include <wx/filename.h>
 
 #include "gexecute.h"
 #include "errors.h"
-#include "chooselang.h"
+
+// GCC's libstdc++ didn't have functional std::regex implementation until 4.9
+#if (defined(__GNUC__) && !defined(__clang__) && !wxCHECK_GCC_VERSION(4,9))
+    #include <boost/regex.hpp>
+    using boost::wregex;
+    using boost::wsmatch;
+    using boost::regex_match;
+#else
+    #include <regex>
+    using std::wregex;
+    using std::wsmatch;
+    using std::regex_match;
+#endif
 
 namespace
 {
 
-#if defined(__WXMAC__) || defined(__WXMSW__)
-
-wxString GetGettextPackagePath()
+#ifdef __WXOSX__
+wxString GetGettextPluginPath()
 {
-#ifdef __WXMAC__
-    wxString dir = wxStandardPaths::Get().GetPluginsDir();
-    return dir + "/GettextTools.bundle/Contents/MacOS";
-#else
-    return wxStandardPaths::Get().GetDataDir() + wxFILE_SEP_PATH + "GettextTools";
-#endif
+    return wxStandardPaths::Get().GetPluginsDir() + "/GettextTools.bundle";
 }
+#endif // __WXOSX__
+
+#if defined(__WXOSX__) || defined(__WXMSW__)
 
 inline wxString GetAuxBinariesDir()
 {
@@ -78,7 +87,7 @@ wxString GetPathToAuxBinary(const wxString& program)
         return program;
     }
 }
-#endif // __WXMAC__ || __WXMSW__
+#endif // __WXOSX__ || __WXMSW__
 
 
 bool ReadOutput(wxInputStream& s, wxArrayString& out)
@@ -106,18 +115,24 @@ long DoExecuteGettext(const wxString& cmdline_, wxArrayString& gstderr)
     wxExecuteEnv env;
     wxString cmdline(cmdline_);
 
-#if defined(__WXMAC__) || defined(__WXMSW__)
+#if defined(__WXOSX__) || defined(__WXMSW__)
     wxString binary = cmdline.BeforeFirst(_T(' '));
     cmdline = GetPathToAuxBinary(binary) + cmdline.Mid(binary.length());
     wxGetEnvMap(&env.env);
-    env.env["POEDIT_USE_UTF8"] = "1";
-    env.env["POEDIT_LOCALEDIR"] = GetGettextPackagePath() + "/share/locale";
-    #if NEED_CHOOSELANG_UI
-	wxString lang = GetUILanguage();
+    env.env["GETTEXTIOENCODING"] = "UTF-8";
+
+    wxString lang = wxTranslations::Get()->GetBestTranslation("gettext-tools");
 	if ( !lang.empty() )
-		env.env["LANG"] = lang;
-    #endif
-#endif // __WXMAC__ || __WXMSW__
+        env.env["LANG"] = lang;
+#endif // __WXOSX__ || __WXMSW__
+
+#ifdef __WXOSX__
+    // Hack alert! On Windows, relocation works, but building with it is too
+    // messy/broken on OS X, so just use some custom hacks instead:
+    auto sharedir = GetGettextPackagePath() + "/share";
+    env.env["POEDIT_LOCALEDIR"] = sharedir + "/locale";
+    env.env["GETTEXTDATADIR"] = sharedir + "/gettext";
+#endif
 
     wxLogTrace("poedit.execute", "executing: %s", cmdline.c_str());
 
@@ -160,23 +175,22 @@ bool ExecuteGettextAndParseOutput(const wxString& cmdline, GettextErrors& errors
     wxArrayString gstderr;
     long retcode = DoExecuteGettext(cmdline, gstderr);
 
-    wxRegEx reError(".*\\.po:([0-9]+)(:[0-9]+)?: (.*)");
+    static const wregex RE_ERROR(L".*\\.po:([0-9]+)(:[0-9]+)?: (.*)");
 
-    for ( size_t i = 0; i < gstderr.size(); i++ )
+    for (const auto& ewx: gstderr)
     {
-        const wxString e = gstderr[i];
-        wxLogTrace("poedit.execute", "  stderr: %s", e.c_str());
+        const auto e = ewx.ToStdWstring();
+        wxLogTrace("poedit", "  stderr: %s", e.c_str());
         if ( e.empty() )
             continue;
 
         GettextError rec;
 
-        if ( reError.Matches(e) )
+        wsmatch match;
+        if (regex_match(e, match, RE_ERROR))
         {
-            long num = -1;
-            reError.GetMatch(e, 1).ToLong(&num);
-            rec.line = (int)num;
-            rec.text = reError.GetMatch(e, 3);
+            rec.line = std::stoi(match.str(1));
+            rec.text = match.str(3);
             errors.push_back(rec);
             wxLogTrace("poedit.execute",
                        _T("        => parsed error = \"%s\" at %d"),
@@ -201,3 +215,16 @@ wxString QuoteCmdlineArg(const wxString& s)
 #endif
     return "\"" + s2 + "\"";
 }
+
+
+#if defined(__WXOSX__) || defined(__WXMSW__)
+wxString GetGettextPackagePath()
+{
+#if defined(__WXOSX__)
+    return GetGettextPluginPath() + "/Contents/MacOS";
+#elif defined(__WXMSW__)
+    return wxStandardPaths::Get().GetDataDir() + wxFILE_SEP_PATH + "GettextTools";
+#endif
+}
+#endif // __WXOSX__ || __WXMSW__
+
