@@ -1,7 +1,7 @@
 ﻿/*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2015 Vaclav Slavik
+ *  Copyright (C) 2015-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -27,8 +27,8 @@
 #define Poedit_hidpi_h
 
 #include <wx/defs.h>
-class WXDLLIMPEXP_BASE wxString;
-class WXDLLIMPEXP_CORE wxBitmap;
+class WXDLLIMPEXP_FWD_BASE wxString;
+class WXDLLIMPEXP_FWD_CORE wxBitmap;
 
 #ifdef __WXMSW__
     #define NEEDS_MANUAL_HIDPI 1
