@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2015 Vaclav Slavik
+ *  Copyright (C) 2015-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -71,6 +71,16 @@ std::string multipart_form_data::body() const
 }
 
 
+void urlencoded_data::add_value(const std::string& name, const std::string& value)
+{
+    if (!m_body.empty())
+        m_body += '&';
+    m_body += name;
+    m_body += '=';
+    m_body += http_client::url_encode(value);
+}
+
+
 std::string http_client::url_encode(const std::string& s)
 {
     std::ostringstream escaped;
@@ -86,6 +96,10 @@ std::string http_client::url_encode(const std::string& s)
         {
             escaped << c;
         }
+        else if (c == ' ')
+        {
+            escaped << '+';
+        }
         else
         {
             escaped << '%' << std::setw(2) << int((unsigned char)c);
