@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2014-2015 Vaclav Slavik
+ *  Copyright (C) 2014-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -30,6 +30,12 @@
 
 #include <boost/algorithm/string/predicate.hpp>
 
+#include <boost/iostreams/copy.hpp>
+#include <boost/iostreams/device/array.hpp>
+#include <boost/iostreams/device/back_inserter.hpp>
+#include <boost/iostreams/filter/gzip.hpp>
+#include <boost/iostreams/filtering_stream.hpp>
+
 #include <cpprest/asyncrt_utils.h>
 #include <cpprest/http_client.h>
 #include <cpprest/http_msg.h>
@@ -38,6 +44,8 @@
 #ifdef _WIN32
     #include <windows.h>
     #include <wininet.h>
+    #include <netlistmgr.h>
+    #pragma comment(lib, "ole32.lib")
 #endif
 
 using namespace web;
@@ -52,6 +60,43 @@ using utility::conversions::to_string_t;
 inline string_t to_string_t(const std::wstring& s) { return str::to_utf8(s); }
 #endif
 
+class gzip_compression_support : public http::http_pipeline_stage
+{
+public:
+    pplx::task<http::http_response> propagate(http::http_request request) override
+    {
+        request.headers().add(http::header_names::accept_encoding, L"gzip");
+
+        return next_stage()->propagate(request).then([](http::http_response response) -> pplx::task<http::http_response>
+        {
+            string_t encoding;
+            if (response.headers().match(http::header_names::content_encoding, encoding) && encoding == _XPLATSTR("gzip"))
+            {
+                return response.extract_vector().then([response](std::vector<unsigned char> compressed) mutable -> http::http_response
+                {
+                    namespace io = boost::iostreams;
+
+                    io::array_source source(reinterpret_cast<char*>(compressed.data()), compressed.size());
+                    io::filtering_istream in;
+                    in.push(io::gzip_decompressor());
+                    in.push(source);
+
+                    std::vector<char> decompressed;
+                    io::back_insert_device<std::vector<char>> sink(decompressed);
+                    io::copy(in, sink);
+
+                    response.set_body(concurrency::streams::bytestream::open_istream(std::move(decompressed)), decompressed.size());
+                    return response;
+                });
+            }
+            else
+            {
+                return pplx::task_from_result(response);
+            }
+        });
+    }
+};
+
 } // anonymous namespace
 
 struct json_dict::native
@@ -93,17 +138,7 @@ std::wstring json_dict::wstring(const char *name) const
 
 int json_dict::number(const char *name) const
 {
-    auto& val = m_native->get(name);
-    if (val.is_integer())
-    {
-        return val.as_integer();
-    }
-    else
-    {
-        // Some broken APIs may return strings instead of numbers, so lets try
-        // that too as a fallback
-        return std::stoi(val.as_string());
-    }
+    return m_native->get(name).as_integer();
 }
 
 double json_dict::double_number(const char *name) const
@@ -135,22 +170,42 @@ public:
         #define make_wide_str_(x) L ## x
 
         #if defined(_WIN32)
-            #define USER_AGENT_PLATFORM L" (Windows)"
+            #define USER_AGENT_PLATFORM L" (Windows NT " + windows_version() + L")"
         #elif defined(__unix__)
             #define USER_AGENT_PLATFORM L" (Unix)"
         #else
             #define USER_AGENT_PLATFORM
         #endif
         m_userAgent = L"Poedit/" make_wide_str(POEDIT_VERSION) USER_AGENT_PLATFORM;
+
+        std::shared_ptr<http::http_pipeline_stage> gzip_stage = std::make_shared<gzip_compression_support>();
+        m_native.add_handler(gzip_stage);
+
+    #ifdef _WIN32
+        m_networkListManager = nullptr;
+        CoCreateInstance(CLSID_NetworkListManager, NULL, CLSCTX_ALL, IID_INetworkListManager, (LPVOID *)&m_networkListManager);
+    #endif
     }
 
     ~impl()
     {
+    #ifdef _WIN32
+        if (m_networkListManager)
+            m_networkListManager->Release();
+    #endif
     }
 
     bool is_reachable() const
     {
     #ifdef _WIN32
+        if (m_networkListManager)
+        {
+            NLM_CONNECTIVITY result;
+            HRESULT hr = m_networkListManager->GetConnectivity(&result);
+            if (SUCCEEDED(hr))
+                return result & (NLM_CONNECTIVITY_IPV4_INTERNET|NLM_CONNECTIVITY_IPV6_INTERNET);
+        }
+        // XP or manager fallback (IPv6 ignorant):
         DWORD flags;
         return ::InternetGetConnectedState(&flags, 0);
     #else
@@ -227,7 +282,7 @@ public:
         });
     }
 
-    void post(const std::string& url, const multipart_form_data& data, response_func_t handler)
+    void post(const std::string& url, const http_body_data& data, response_func_t handler)
     {
         http::http_request req(http::methods::POST);
         req.headers().add(http::header_names::accept,     L"application/json");
@@ -244,7 +299,7 @@ public:
         .then([=](http::http_response response)
         {
             handle_error(response);
-            handler(json_dict());
+            handler(make_json_dict(response.extract_json().get()));
         })
         .then([=](pplx::task<void> t)
         {
@@ -291,11 +346,7 @@ private:
             // hosts that use it. The use of SNI is increasingly common and some
             // APIs Poedit needs to connect to use it. To keep things simple, just
             // disable SSL on Windows XP.
-            OSVERSIONINFOEX info;
-            ZeroMemory(&info, sizeof(info));
-            info.dwOSVersionInfoSize = sizeof(info);
-            GetVersionEx(reinterpret_cast<OSVERSIONINFO*>(&info));
-            if (info.dwMajorVersion < 6) // XP
+            if (is_windows_xp())
             {
                 if (boost::starts_with(url, "https://"))
                     return U("http://") + string_t(url.begin() + 8, url.end());
@@ -306,6 +357,28 @@ private:
     }
 
 private:
+#ifdef _WIN32
+    static bool is_windows_xp()
+    {
+        OSVERSIONINFOEX info;
+        ZeroMemory(&info, sizeof(info));
+        info.dwOSVersionInfoSize = sizeof(info);
+        GetVersionEx(reinterpret_cast<OSVERSIONINFO*>(&info));
+        return (info.dwMajorVersion < 6); // XP
+    }
+
+    static std::wstring windows_version()
+    {
+        OSVERSIONINFOEX info;
+        ZeroMemory(&info, sizeof(info));
+        info.dwOSVersionInfoSize = sizeof(info);
+        GetVersionEx(reinterpret_cast<OSVERSIONINFO*>(&info));
+        return std::to_wstring(info.dwMajorVersion) + L"." + std::to_wstring(info.dwMinorVersion);
+    }
+
+    INetworkListManager *m_networkListManager;
+#endif
+
     http_client& m_owner;
     http::client::http_client m_native;
     std::wstring m_userAgent;
@@ -344,7 +417,7 @@ void http_client::download(const std::string& url, const std::wstring& output_fi
     m_impl->download(url, output_file, handler);
 }
 
-void http_client::post(const std::string& url, const multipart_form_data& data, response_func_t handler)
+void http_client::post(const std::string& url, const http_body_data& data, response_func_t handler)
 {
     m_impl->post(url, data, handler);
 }
