@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2004-2014 Vaclav Slavik
+ *  Copyright (C) 2004-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
     #define HAS_THEMES_SUPPORT
 #endif
 
-#ifndef __WXMAC__
+#ifndef __WXOSX__
 class PoeditArtProvider : public wxArtProvider
 {
 protected:
