@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2013-2014 Vaclav Slavik
+ *  Copyright (C) 2013-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -25,8 +25,6 @@
 
 #include "language.h"
 
-#include "icuhelpers.h"
-
 #include <cctype>
 #include <algorithm>
 #include <unordered_map>
@@ -40,6 +38,18 @@
 
 #include <wx/filename.h>
 
+#include "str_helpers.h"
+
+#ifdef HAVE_CLD2
+    #ifdef HAVE_CLD2_PUBLIC_COMPACT_LANG_DET_H
+        #include <cld2/public/compact_lang_det.h>
+        #include <cld2/public/encodings.h>
+    #else
+        #include "public/compact_lang_det.h"
+        #include "public/encodings.h"
+    #endif
+#endif
+
 // GCC's libstdc++ didn't have functional std::regex implementation until 4.9
 #if (defined(__GNUC__) && !defined(__clang__) && !wxCHECK_GCC_VERSION(4,9))
     #include <boost/regex.hpp>
@@ -169,11 +179,11 @@ const DisplayNamesData& GetDisplayNamesData()
             }
             
             s.foldCase();
-            data.names[StdFromIcuStr(s)] = code;
+            data.names[str::to_wstring(s)] = code;
 
             loc->getDisplayName(locEng, s);
             s.foldCase();
-            data.namesEng[StdFromIcuStr(s)] = code;
+            data.namesEng[str::to_wstring(s)] = code;
         }
 
         // sort the names alphabetically for data.sortedNames:
@@ -197,7 +207,7 @@ const DisplayNamesData& GetDisplayNamesData()
         // convert into std::wstring
         data.sortedNames.reserve(names.size());
         for (auto s: names)
-            data.sortedNames.push_back(StdFromIcuStr(s));
+            data.sortedNames.push_back(str::to_wstring(s));
     });
 
     return data;
@@ -239,6 +249,16 @@ std::string Language::Variant() const
         return m_code.substr(0, pos);
 }
 
+std::string Language::RFC3066() const
+{
+    auto c = Country();
+    auto l = Lang();
+    if (c.empty())
+        return l;
+    else
+        return l + "-" + c;
+}
+
 
 Language Language::TryParse(const std::wstring& s)
 {
@@ -256,9 +276,9 @@ Language Language::TryParse(const std::wstring& s)
 
     // If not, perhaps it's a human-readable name (perhaps coming from the language control)?
     auto names = GetDisplayNamesData();
-    icu::UnicodeString s_icu = ToIcuStr(s);
+    icu::UnicodeString s_icu = str::to_icu(s);
     s_icu.foldCase();
-    std::wstring folded = StdFromIcuStr(s_icu);
+    std::wstring folded = str::to_wstring(s_icu);
     auto i = names.names.find(folded);
     if (i != names.names.end())
         return Language(i->second);
@@ -371,7 +391,14 @@ wxString Language::DisplayName() const
 {
     icu::UnicodeString s;
     ToIcu().getDisplayName(s);
-    return FromIcuStr(s);
+    return str::to_wx(s);
+}
+
+wxString Language::LanguageDisplayName() const
+{
+    icu::UnicodeString s;
+    ToIcu().getDisplayLanguage(s);
+    return str::to_wx(s);
 }
 
 wxString Language::DisplayNameInItself() const
@@ -379,7 +406,7 @@ wxString Language::DisplayNameInItself() const
     auto loc = ToIcu();
     icu::UnicodeString s;
     loc.getDisplayName(loc, s);
-    return FromIcuStr(s);
+    return str::to_wx(s);
 }
 
 wxString Language::FormatForRoundtrip() const
@@ -448,3 +475,56 @@ Language Language::TryGuessFromFilename(const wxString& filename)
 
     return Language(); // failed to match
 }
+
+
+Language Language::TryDetectFromText(const char *buffer, size_t len, Language probableLanguage)
+{
+#ifdef HAVE_CLD2
+    using namespace CLD2;
+
+    CLDHints hints = {NULL, NULL, UNKNOWN_ENCODING, UNKNOWN_LANGUAGE};
+    if (probableLanguage.IsValid())
+    {
+        if (probableLanguage.Lang() == "en")
+            hints.language_hint = ENGLISH;
+        else
+            hints.language_hint = GetLanguageFromName(probableLanguage.RFC3066().c_str());
+    }
+
+    // three best guesses; we don't care, but they must be passed in
+    CLD2::Language language3[3];
+    int percent3[3];
+    double normalized_score3[3];
+    // more result info:
+    int text_bytes;
+    bool is_reliable;
+
+    auto lang = CLD2::ExtDetectLanguageSummary(
+                        buffer, (int)len,
+                        /*is_plain_text=*/true, // any embedded HTML markup should be insignificant
+                        &hints,
+                        /*flags=*/0,
+                        language3, percent3, normalized_score3,
+                        /*resultchunkvector=*/nullptr,
+                        &text_bytes,
+                        &is_reliable);
+
+    if (lang == UNKNOWN_LANGUAGE || !is_reliable)
+        return Language();
+
+    // CLD2 penalizes English in bilingual content in some cases as "boilerplate"
+    // because it is tailored for the web. So e.g. 66% English, 33% Italian is
+    // tagged as Italian.
+    //
+    // Poedit's bias is the opposite: English is almost always the correct answer
+    // for PO source language. Fix this up manually.
+    if (lang != language3[0] && language3[0] == CLD2::ENGLISH && language3[1] == lang)
+        lang = language3[0];
+
+    return Language::TryParse(LanguageCode(lang));
+#else
+    (void)buffer;
+    (void)len;
+    return probableLanguage;
+#endif
+}
