@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2000-2015 Vaclav Slavik
+ *  Copyright (C) 2000-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -62,6 +62,7 @@ class PropertiesDialog : public wxDialog
         void OnPluralFormsCustom(wxCommandEvent& event);
 
         struct PathsData;
+        class BasePathCtrl;
         class PathsList;
         class SourcePathsList;
         class ExcludedPathsList;
@@ -71,7 +72,7 @@ class PropertiesDialog : public wxDialog
         wxComboBox *m_charset, *m_sourceCodeCharset;
         wxRadioButton *m_pluralFormsDefault, *m_pluralFormsCustom;
         wxTextCtrl *m_pluralFormsExpr;
-        wxTextCtrl *m_basePath;
+        BasePathCtrl *m_basePath;
         std::shared_ptr<PathsData> m_pathsData;
         PathsList *m_paths, *m_excludedPaths;
         wxEditableListBox *m_keywords;
