@@ -1,7 +1,7 @@
 ﻿/*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2014-2015 Vaclav Slavik
+ *  Copyright (C) 2014-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -43,6 +43,7 @@
 #include <wx/sizer.h>
 #include <wx/statbmp.h>
 #include <wx/stattext.h>
+#include <wx/time.h>
 #include <wx/wupdlock.h>
 
 #include <algorithm>
@@ -144,8 +145,7 @@ public:
 
     void Update(const CatalogItemPtr& item) override
     {
-        auto txt = wxJoin(item->GetOldMsgid(), ' ', '\0');
-        m_text->SetAndWrapLabel(txt);
+        m_text->SetAndWrapLabel(item->GetOldMsgid());
     }
 
 private:
@@ -206,6 +206,7 @@ public:
     {
         auto text = CommentDialog::RemoveStartHash(item->GetComment());
         text.Trim();
+        m_comment->SetLanguage(m_parent->GetCurrentLanguage());
         m_comment->SetAndWrapLabel(text);
     }
 
@@ -288,7 +289,7 @@ public:
         }
     }
 
-    void SetValue(int index, const Suggestion& s, bool isRTL, const wxBitmap& icon, const wxString& tooltip)
+    void SetValue(int index, const Suggestion& s, Language lang, bool isRTL, const wxBitmap& icon, const wxString& tooltip)
     {
         m_value = s;
 
@@ -325,6 +326,7 @@ public:
             isRTL = !isRTL;
 
         m_text->SetAlignment(isRTL ? wxALIGN_RIGHT : wxALIGN_LEFT);
+        m_text->SetLanguage(lang);
         m_text->SetAndWrapLabel(text);
 
 #ifndef __WXOSX__
@@ -393,7 +395,8 @@ SuggestionsSidebarBlock::SuggestionsSidebarBlock(Sidebar *parent, wxMenu *menu)
       m_suggestionsMenu(menu),
       m_msgPresent(false),
       m_pendingQueries(0),
-      m_latestQueryId(0)
+      m_latestQueryId(0),
+      m_lastUpdateTime(0)
 {
     m_provider.reset(new SuggestionsProvider);
 
@@ -428,6 +431,11 @@ SuggestionsSidebarBlock::SuggestionsSidebarBlock(Sidebar *parent, wxMenu *menu)
     m_innerSizer->Add(m_iGotNothing, wxSizerFlags().Center().Border(wxTOP|wxBOTTOM, PX(100)));
 
     BuildSuggestionsMenu();
+
+    m_suggestionsTimer.SetOwner(parent);
+    parent->Bind(wxEVT_TIMER,
+                 &SuggestionsSidebarBlock::OnDelayedShowSuggestionsForItem, this,
+                 m_suggestionsTimer.GetId());
 }
 
 SuggestionsSidebarBlock::~SuggestionsSidebarBlock()
@@ -468,7 +476,6 @@ void SuggestionsSidebarBlock::ReportError(SuggestionsBackend*, std::exception_pt
 
 void SuggestionsSidebarBlock::ClearSuggestions()
 {
-    m_pendingQueries = 0;
     m_suggestions.clear();
     UpdateSuggestionsMenu();
     UpdateVisibility();
@@ -497,11 +504,12 @@ void SuggestionsSidebarBlock::UpdateSuggestions(const SuggestionsList& hits)
     m_innerSizer->Layout();
 
     // update shown suggestions:
-    bool isRTL = m_parent->GetCurrentLanguage().IsRTL();
+    auto lang = m_parent->GetCurrentLanguage();
+    bool isRTL = lang.IsRTL();
     for (size_t i = 0; i < m_suggestions.size(); ++i)
     {
         auto s = m_suggestions[i];
-        m_suggestionsWidgets[i]->SetValue((int)i, s, isRTL, GetIconForSuggestion(s), GetTooltipForSuggestion(s));
+        m_suggestionsWidgets[i]->SetValue((int)i, s, lang, isRTL, GetIconForSuggestion(s), GetTooltipForSuggestion(s));
     }
 
     m_innerSizer->Layout();
@@ -627,11 +635,35 @@ bool SuggestionsSidebarBlock::ShouldShowForItem(const CatalogItemPtr&) const
 
 void SuggestionsSidebarBlock::Update(const CatalogItemPtr& item)
 {
-    // FIXME: Cancel previous pending async operation if any
-
     ClearMessage();
     ClearSuggestions();
 
+    UpdateSuggestionsForItem(item);
+}
+
+void SuggestionsSidebarBlock::UpdateSuggestionsForItem(CatalogItemPtr item)
+{
+    if (!item)
+        return;
+
+    long long now = wxGetUTCTimeMillis().GetValue();
+    long long delta = now - m_lastUpdateTime;
+    m_lastUpdateTime = now;
+
+    if (delta < 100)
+    {
+        // User is probably holding arrow down and going through the list as crazy
+        // and not really caring for the suggestions. Throttle them a bit and call
+        // this code after a small delay. Notice that this may repeat itself several
+        // times, only continuing through to show suggestions after the dust settled
+        // and the user didn't change the selection for a few milliseconds.
+        if (!m_suggestionsTimer.IsRunning())
+            m_suggestionsTimer.StartOnce(110);
+        return;
+    }
+
+    m_pendingQueries = 0;
+
     auto srclang = m_parent->GetCurrentSourceLanguage();
     auto lang = m_parent->GetCurrentLanguage();
     if (!srclang.IsValid() || !lang.IsValid() || srclang == lang)
@@ -643,6 +675,11 @@ void SuggestionsSidebarBlock::Update(const CatalogItemPtr& item)
     QueryAllProviders(item);
 }
 
+void SuggestionsSidebarBlock::OnDelayedShowSuggestionsForItem(wxTimerEvent&)
+{
+    UpdateSuggestionsForItem(m_parent->GetSelectedItem());
+}
+
 void SuggestionsSidebarBlock::QueryAllProviders(const CatalogItemPtr& item)
 {
     auto thisQueryId = ++m_latestQueryId;
