@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2014 Vaclav Slavik
+ *  Copyright (C) 2014-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -28,16 +28,6 @@
 
 #include <wx/defs.h>
 
-#ifndef USE_SPELLCHECKING
-    #if defined(__WXOSX__) || defined(__WXMSW__)
-        #define USE_SPELLCHECKING 1
-    #else
-        #define USE_SPELLCHECKING 0
-    #endif
-#endif
-
-#if USE_SPELLCHECKING
-
 #ifdef __WXMSW__
     #include <wx/platinfo.h>
 #endif
@@ -73,10 +63,4 @@ bool InitTextCtrlSpellchecker(wxTextCtrl *text, bool enable, const Language& lan
 void ShowSpellcheckerHelp();
 #endif
 
-#else // !USE_SPELLCHECKING
-
-inline bool IsSpellcheckingAvailable() { return false; }
-
-#endif
-
 #endif // Poedit_spellchecking_h
