@@ -1,7 +1,7 @@
 ﻿/*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 1999-2015 Vaclav Slavik
+ *  Copyright (C) 1999-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -732,7 +732,7 @@ void TranslationTextCtrl::OnText(wxCommandEvent& e)
         m_lastKeyWasReturn = false;
         long pos = GetInsertionPoint();
         auto range = GetRange(std::max(0l, pos - 3), pos);
-        if (range.Last() == '\n' && range != "\\n\n")
+        if (range.empty() || (range.Last() == '\n' && range != "\\n\n"))
         {
           #ifdef __WXGTK__
             // GTK+ doesn't like modifying the content in the "changed" signal:
