@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://poedit.net)
  *
- *  Copyright (C) 2014-2015 Vaclav Slavik
+ *  Copyright (C) 2014-2016 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -42,8 +42,8 @@ public:
     {
         auto bck = &backend;
         concurrency_queue::add([=](){
-            // don't bother asking the backend if the language is invalid:
-            if (!lang.IsValid())
+            // don't bother asking the backend if the language or query is invalid:
+            if (!srclang.IsValid() || !lang.IsValid() || srclang == lang || source.empty())
             {
                 onSuccess(SuggestionsList());
                 return;
